# source_and_license

A lightweight solution to adding license to all source files, in Python

Open source available on [GitHub](https://github.com/Whoeza/source_and_license) and
[PyPI](https://pypi.org/project/source_and_license/).

## Installation

Install from pip:

`py -m pip install source_and_license`

Update to the latest version from pip:

`py -m pip install --upgrade source_and_license`

Uninstall from pip:

`py -m pip uninstall source_and_license`

### Building from sources

Run this command from the package directory on your filesystem:

`py -m build`

### Development diary

[DEVDIARY.md](https://github.com/Whoeza/source_and_license/blob/main/DEVDIARY.md)

## Community

[Open a new issue](https://github.com/Whoeza/source_and_license/issues) for
support.
